/*
 * Copyright (c) 2004, 2005, ADAPT project partners (IST-2001-37126).
 * 
 * RestockServlet.java
 */

package org.eu.adapt.demonstrator.web.demo;

import java.io.*;
import java.net.URL;
import javax.servlet.*;
import javax.servlet.http.*;
import org.eu.adapt.demonstrator.web.ADAPTLookAndFeel;
import org.eu.adapt.demonstrator.web.Navigation;
import org.eu.adapt.services.demo_1_0.ProductionLineBasicService_wsdl.ProductionLineBasicServiceLocator;
import org.eu.adapt.services.demo_1_0.ProductionLineBasicService_wsdl.ProductionLineBasicServicePortType;

public class RestockServlet extends HttpServlet
{
    public void init()
        throws ServletException
    {
    }

    public void doGet(HttpServletRequest request, HttpServletResponse response)
        throws ServletException, IOException 
    {
        response.setContentType("text/html");
        response.setHeader("Cache-Control", "no-cache");

        PrintWriter writer = response.getWriter();

        ADAPTLookAndFeel.generatePageHeader("..", writer);
        Navigation.generateNavigationHeader("..", writer);

        String productionLineName = ManufacturerItemsDefs.PRODUCTION_LINE_0;
        String finishedGoodsID    = ManufacturerItemsDefs.FINISHED_GOODS_0;
        int    amount             = 15;
        
        boolean done = produceStock(productionLineName, finishedGoodsID, amount);
        
        writer.println("<P><B>Restock: ");
        if (done)
            writer.println("Successful</B></P>");
        else
            writer.println("Failed</B></P>");
        
        writer.println("<P>Production Line: " + productionLineName + "</P>");
        writer.println("<P>Finished Goods: " + finishedGoodsID + "</P>");
        writer.println("<P>Amount: " + amount + "</P>");

        Navigation.generateNavigationFooter(writer);
        ADAPTLookAndFeel.generatePageFooter(writer);
    }

    private boolean produceStock(String productionLineName, String finishedGoodsID, int amount)
    {
        boolean done = false;

        try
        {
            String                             productionLineBasicServiceURLString = getInitParameter("ProductionLineBasicServiceURL");
            ProductionLineBasicServiceLocator  productionLineBasicServiceLocator   = new ProductionLineBasicServiceLocator();
            ProductionLineBasicServicePortType productionLineBasicServicePortType  = productionLineBasicServiceLocator.getProductionLine(new URL(productionLineBasicServiceURLString));

            done = productionLineBasicServicePortType.setRestock(productionLineName, finishedGoodsID, amount);
        }
        catch (Exception exception)
        {
            System.err.println("Exception in \"produceStock\": " + exception);
            done = false;
        }
        catch (Error error)
        {
            System.err.println("Error in \"produceStock\": " + error);
            done = false;
        }
        
        return done;
    }
}