/*
 * Copyright (c) 2004, 2005, ADAPT project partners (IST-2001-37126).
 * 
 * SubmitPurchaseOrderServlet.java
 */

package org.eu.adapt.demonstrator.web.demo;

import java.io.*;
import java.net.URL;
import javax.servlet.*;
import javax.servlet.http.*;
import org.eu.adapt.demonstrator.web.ADAPTLookAndFeel;
import org.eu.adapt.demonstrator.web.Navigation;
import org.eu.adapt.services.demo_1_0.ManufacturerService_wsdl.ManufacturerServiceLocator;
import org.ws_i.www.SampleApplications.SupplyChainManagement._2002_08.Configuration_xsd.ConfigurationType;
import org.ws_i.www.SampleApplications.SupplyChainManagement._2002_10.Manufacturer.CallBack.StartHeaderType;
import org.ws_i.www.SampleApplications.SupplyChainManagement._2002_10.ManufacturerPO_xsd.Item;
import org.ws_i.www.SampleApplications.SupplyChainManagement._2002_10.ManufacturerPO_xsd.ItemList;
import org.ws_i.www.SampleApplications.SupplyChainManagement._2002_10.ManufacturerPO_xsd.PurchOrdType;
import org.ws_i.www.SampleApplications.SupplyChainManagement._2002_10.Manufacturer_wsdl.ManufacturerPortType;

public class SubmitPurchaseOrderServlet extends HttpServlet
{
    public void init()
        throws ServletException
    {
    }

    public void doGet(HttpServletRequest request, HttpServletResponse response)
        throws ServletException, IOException 
    {
        response.setContentType("text/html");
        response.setHeader("Cache-Control", "no-cache");

        PrintWriter writer = response.getWriter();

        ADAPTLookAndFeel.generatePageHeader("..", writer);
        Navigation.generateNavigationHeader("..", writer);

        String purchaseOrderNumber = "ON" + _nextOrderNumber;
        _nextOrderNumber++;

        PurchaseOrderList.addPurchaseOrder(purchaseOrderNumber);

        PurchOrdType purchOrdType = new PurchOrdType();
        purchOrdType.setCustomerRef(ManufacturerItemsDefs.CUSTOMER_0);
        purchOrdType.setOrderNum(purchaseOrderNumber);
        purchOrdType.setTotal(100.0f);
        ItemList itemList = new ItemList();
        Item[]   items    = new Item[1];
        items[0] = new Item();
        items[0].setID(ManufacturerItemsDefs.FINISHED_GOODS_0);
        items[0].setQty(10);
        items[0].setPrice(50.0f);
//        items[1] = new Item();
//        items[1].setID(ManufacturerItemsDefs.FINISHED_GOODS_1);
//        items[1].setQty(2);
//        items[1].setPrice(25.0f);
        itemList.setItem(items);
        purchOrdType.setItems(itemList);
        ConfigurationType configuration = new ConfigurationType();
        StartHeaderType startHeader = new StartHeaderType();

        int status = submitPurchaseOrder(purchOrdType, configuration, startHeader);
        
        PurchaseOrderList.setPurchaseOrderStatus(purchaseOrderNumber, status);
        writer.println("<P>Purchase Order Number: " + purchaseOrderNumber + ", Status: " + PurchaseOrder.statusToString(status) + "</P>");

        Navigation.generateNavigationFooter(writer);
        ADAPTLookAndFeel.generatePageFooter(writer);
    }

    private int submitPurchaseOrder(PurchOrdType purchOrd, ConfigurationType configuration, StartHeaderType startHeader)
    {
        int status = PurchaseOrder.STATUS_UNKNOWN;
        
        try
        {
            String                     manufacturerServiceURLString = getInitParameter("ManufacturerServiceURL");
            ManufacturerServiceLocator manufacturerServiceLocator   = new ManufacturerServiceLocator();
            ManufacturerPortType       manufacturerServicePortType  = manufacturerServiceLocator.getManufacturer(new URL(manufacturerServiceURLString));

            if (manufacturerServicePortType.submitPO(purchOrd, configuration, startHeader))
                status = PurchaseOrder.STATUS_ACKNOWLEDGED;
            else
                status = PurchaseOrder.STATUS_REJECTED;
        }
        catch (Exception exception)
        {
            System.err.println("Exception in \"submitPurchaseOrder\": " + exception);
            status = PurchaseOrder.STATUS_UNACKNOWLEDGED;
        }
        catch (Error error)
        {
            System.err.println("Error in \"submitPurchaseOrder\": " + error);
            status = PurchaseOrder.STATUS_UNACKNOWLEDGED;
        }
        
        return status;
    }

    private int _nextOrderNumber = 1;
}